.. _examples:

Test Cases and Examples
===============================
In order to ease the use of DMT, some basic examples can be found here.
Note that not all function arguments are explained in the following examples. If you wonder what
one of the arguments does or what other methods exist, look into the technical documentation!
There every argument and function is documented.

.. toctree::
    :maxdepth: 1

    test_cases
    basic_data_handling
    running_a_simulation
    read_in_measurement_data
    readin_dut_lib
